@@ -11,7 +11,7 @@ class LibInventAdapter(GenerativeModelBase):
         self.network = self.generative_model.network
 
     def save_to_file(self, path):
-        self.generative_model.save_to_file(path)
+        self.generative_model.save(path)
 
     def likelihood(self, scaffold_seqs, scaffold_seq_lengths, decoration_seqs, decoration_seq_lengths):
         return self.generative_model.likelihood(scaffold_seqs, scaffold_seq_lengths, decoration_seqs, decoration_seq_lengths)
